@@ -1,6 +1,7 @@
 from http.server import HTTPServer, BaseHTTPRequestHandler
 from socket import gethostbyname, gethostname
 import json
+from eqsmart.main.provider import not_c_key
 
 
 def preset_get_params(request):
@@ -86,7 +87,7 @@ def http_server(server_conf, server_list):
     :param server_list: http服务列表
     :return: http服务器对象
     """
-    host = gethostbyname(gethostname())
+    host = gethostbyname(gethostname()) if not_c_key(server_conf, 'HOST') else server_conf['HOST']
     mhs = MyHttpServer
     mhs.my_server_list = server_list
     print(f"[eqsmart] HTTP Server starting on {host}:{server_conf['PORT']}")
