@@ -19,7 +19,7 @@ class RemoteCall:
     def __init__(self, service_path):
         self.service_path = service_path
 
-    def func_call(self, params):
+    def func_call(self, params, buf_size=204800):
         if type(params) is tuple:
             protocol['args'] = params
             protocol['kwargs'] = {}
@@ -41,6 +41,13 @@ class RemoteCall:
             weight_check[str(count_w)] = item['weight']
             count_w = count_w + 1
             count_c = int(item['weight']) + count_c
+        if count_c == 0:
+            res_error = {
+                'code': 'remote_call_error',
+                'message': '远程服务权重计算失败，服务可能不存在',
+                'data': protocol
+            }
+            return res_error
         weight_factor = math.ceil(100 / count_c)  # 权重因子
         weight_m = 0  # 中间值
         call_random = random.randint(0, 100)  # 随机数
@@ -57,7 +64,7 @@ class RemoteCall:
         provider_conf = {
             'IP': provider_server[call_weight]['ip'],  # 远程服务器地址
             'PORT': provider_server[call_weight]['port'],  # 远程服务器端口
-            'BUF_SIZE': 4096  # 消息读取长度
+            'BUF_SIZE': buf_size  # 消息读取长度
         }
         print('[eqsmart] 远程调用', provider_conf, protocol)
         try:
